@@ -16,6 +16,7 @@ class ModelAdmin(object):
     """
     paginate_by = 20
     columns = None
+    ignore_filters = ('ordering', 'page',)
     
     def __init__(self, admin, model):
         self.admin = admin
@@ -82,7 +83,7 @@ class ModelAdmin(object):
         filters = []
         raw_filters = []
         for key in request.args:
-            if key in ('ordering', 'page'):
+            if key in self.ignore_filters:
                 continue
             
             values = request.args.getlist(key)
